Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config map[string][]*Downloader
Config map binary names to Config
func LoadConfig ¶
LoadConfig returns a Config from a config reader
func LoadConfigFile ¶
LoadConfigFile returns a Config from the path to a config file
func (Config) Downloader ¶
func (c Config) Downloader(binary, os, arch string) *Downloader
Downloader returns a Downloader for the given binary, os and arch.
type Downloader ¶
type Downloader struct {
URL string `json:"url"`
Checksum string `json:"checksum"`
BinName string `json:"bin"`
ArchivePath string `json:"archive_path"`
Link bool `json:"link"`
OS string `json:"os"`
Arch string `json:"arch"`
// Deprecated: use ArchivePath
MoveFrom string `json:"move-from"`
// Deprecated: use ArchivePath and Link
LinkSource string `json:"symlink,omitempty"`
}
Downloader downloads a binary
func (*Downloader) Install ¶
func (d *Downloader) Install(opts InstallOpts) error
Install downloads and installs a bin
type InstallOpts ¶
type InstallOpts struct {
// DownloaderName is the downloader's key from the config file
DownloaderName string
// CellarDir is the directory where downloads and extractions will be placed. Default is a <TargetDir>/.bindownloader
CellarDir string
// TargetDir is the directory where the executable should end up
TargetDir string
// Force - whether to force the install even if it already exists
Force bool
}
InstallOpts options for Install
Click to show internal directories.
Click to hide internal directories.